/* wheaties.h
 *
 * Declarations to make programing for /dev/wheaties a bit easier.
 * I hope this makes sense. This file format may change a bit over
 * time to suit everyones needs or correct errors. Hopefully, things
 * will only get added to the file.
 *
 * Written by John Laur <johnl@blurbco.com> 10/20/2001
 * 
 * Share and enjoy.
 */

/* ------------------ *
 * ---- Commands ---- *
 * ------------------ */

/* Commands to get and set the DSP clock */
#define CMD_TIME_SET		0x50	/* Set the DSP Clock */
#define CMD_TIME_GET		0x52	/* Get the DSP Clock */

/* Commands to control the volume */
#define CMD_VOLUME		0x4C	/* Volume Functions */

#define VOLUME_HANDSET		0x00	/* Handset Volume 0-3 */
#define VOLUME_SPEAKER		0x10	/* Speakerphone Volume 0-7 */
#define VOLUME_AM		0x20	/* ??? 0-7 */
#define VOLUME_RINGER		0x30	/* Ring Volume 0-7 */

/* CallerID Commands and parameters */
#define CMD_CALLERID		0x22	/* CallerID Functions */

#define CALLERID_REPORT		0x25 /* Report CallerID Settings */
#define CALLERID_NEW		0x20 /* New CallerID Data */
#define CALLERID_GET_1		0x09 /* Get CallerID Block 1 */
#define CALLERID_BLOCK1		0x27 /* Number/Date/Time */
#define CALLERID_GET_2		0x0A /* Get CallerID Block 2 */
#define CALLERID_BLOCK2		0x28 /* Name */
#define CALLERID_SET_ALL	0x13 /* Set all CallerID options */
#define CALLERID_SET_ALL_NOCW	0x03 /* Except for Call Waiting */

#define CMD_CALLERID_SETOPTS	0x17 /* Set CallerID Options */
#define CMD_CALLERID_GETOPTS	0x18 /* Get CallerID Options */

/* Commands for dialtone detection */
#define CMD_DIALTONEDETECT_ON	0x1A	/* Start dialtone detect */
#define CMD_DIALTONEDETECT_OFF	0x1B	/* Abort dialtone detect */

#define DIALTONEDETECT_STUTTER	0x34	/* Detected stutter dialtone */
#define DIALTONEDETECT_NORMAL	0x35	/* Detected normal dialtone */
#define DIALTONEDETECT_ERROR	0x36	/* No dialtone detected */

/* Play rings/alert tones */
#define CMD_TONE		0x42	/* Tone/Sound functions */

#define TONE_DEST_SPK		0x01	/* Loudspeaker */
#define TONE_DEST_LINE1		0x02	/* Line One */
#define TONE_DEST_LINE2		0x03	/* Line 2? */
#define TONE_DEST_WH		0x04	/* ??? Handset? */
#define TONE_DEST_CH		0x10	/* ??? Handset? */

#define TONE_RING		0x01	/* Normal Single Ring */
#define TONE_RING_P		0x08	/* Priority Ring */
#define TONE_RING_3S		0x03	/* 3 Short Rings */
#define TONE_HAPPY		0x04	/* HAPPY TONE!!! :)) */
#define TONE_BEEP_2S		0x08	/* Short Double Beeps */
#define TONE_BEEP_1M		0x0A	/* Medium Single Beep */
#define TONE_BEEP_3M		0x07	/* Triple Medium Beeps */
#define TONE_BEEP_1L		0x02	/* One Long Beep */
#define TONE_BUZZER		0x05	/* SAD TONE :(( Buzzer */

/* Make the DSP perform dialing actions */
#define CMD_DIAL		0x58	/* Dialing functions */

#define DIAL_DTMF_0		0x0A	/* DTMF 0 */
#define DIAL_DTMF_1		0x01	/* DTMF 1 */
#define DIAL_DTMF_2		0x02	/* DTMF 2 */
#define DIAL_DTMF_3		0x03	/* DTMF 3 */
#define DIAL_DTMF_4		0x04	/* DTMF 4 */
#define DIAL_DTMF_5		0x05	/* DTMF 5 */
#define DIAL_DTMF_6		0x06	/* DTMF 6 */
#define DIAL_DTMF_7		0x07	/* DTMF 7 */
#define DIAL_DTMF_8		0x08	/* DTMF 8 */
#define DIAL_DTMF_9		0x09	/* DTMF 9 */ 
#define DIAL_DTMF_STAR		0x0B	/* DTMF * */
#define DIAL_DTMF_POUND		0x0C	/* DTMF # */
#define DIAL_PAUSE		0x0E	/* Pause 1 second */
#define DIAL_FLASH		0x0D	/* Flash switchook */
#define DIAL_S			0x0B	/* ??? stop dtmf tone? */
#define DIAL_W			0x0F	/* ??? Wait for dialtone?*/

#define DIAL_MODE_CONST		0x40	/* Continuous DTMF generation */
#define DIAL_MODE_BURST		0x00	/* DTMF Burst */
#define DIAL_MODE_PULSE		0x80	/* Pulse dialing, ick! */

/* Control the LED lights and line relays */
#define CMD_LED			0xA3	/* LED and line relay functions */

#define LED_BLINKSPEED_4	0x00	/* Fastest blink speed */
#define LED_BLINKSPEED_3	0x01	/* Fast blink speed */
#define LED_BLINKSPEED_2	0x02	/* Medium blink speed */
#define LED_BLINKSPEED_1	0x03	/* Slow blink speed */
#define LED_BLINKSPEED_0	0x04	/* Slowestt blink speed */

#define LED_OFF			0x00	/* Off */
#define LED_BLINK_1		0x01	/* Blink (To timer 1) */
#define LED_BLINK_2		0x02	/* Blink (To timer 2) */
#define LED_ON			0x03	/* On */

/* Set the DSP audio paths */
#define CMD_AUDIO		0xA6	/* Audio path functions */

#define AUDIO_IDLE		0x01	/* Idle audio - not routed */
#define AUDIO_HANDSET		0x02	/* Audio routed to handset */
#define AUDIO_SPEAKER		0x0D	/* Audio routed to loudspeaker */
#define AUDIO_HANDSET_MUTE	0x16	/* Audio out only to handset */
#define AUDIO_SPEAKER_MUTE	0x04	/* Audio out only to speaker */

/* Control the telephone line */
#define CMD_LINE		0xA7	/* Line hook functions */

#define LINE_ONHOOK		0x00	/* Put line on hook */
#define LINE_OFFHOOK_HANDSET	0x02	/* Take line off hook on handset */
#define LINE_OFFHOOK_SPEAKER	0x06	/* Take line off hook on speaker */

/* Check the status of the DSP */
#define CMD_SANITY		0xB7	/* DSP Sanity Check */

/* Detect parallel handsets in use on the line */
#define CMD_PARALLEL		0xA2	/* Detect parallel handset pickup */

/* Detect busy signal */
#define CMD_BUSYDETECT_ON	0xAC	/* Detect busy signal on line */
#define CMD_BUSYDETECT_OFF	0xAD	/* Stop detecting for busy signal */

#define BUSYDETECT_ON		0x01
#define BUSYDETECT_OFF		0x02
#define BUSYDETECT_REPORT	0x03

/* ------------------- *
 * ---- Responses ---- *
 * ------------------- */

/* Basic Command Responses */
#define RSP_ACK			0x80	/* Command OK */
#define RSP_NAK			0x84	/* Not OK or Unknown Command */

#define RSP_RING		0x10	/* Ring event */

#define RSP_CALLERID		0x22	/* CallerID Event */

#define RSP_TIME		0xEA	/* Clock response */

#define RSP_BUSY		0x85	/* Response to busy command */

/* Response to DSP Sanity Check */
#define RSP_SANITY		0xDB	/* Response to sanity check */

/* response to line status */
#define RSP_LINE		0xB0	/* Response to line event */

#define LINE_INUSE		0xD8	/* Line is in use */
#define LINE_NOTINUSE		0xD9	/* Line not in use */

/* Response to indicate a delay in responding.. ?!?! */
#define RSP_DELAY		0xB2	/* Command is still processing */

#define RSP_PARALLEL		0x08	/* Parallel set detected */

/* Messages that indicate a button was pushed or released */
#define RSP_BTN			0x04	/* Button Event */

#define	BTN_0			0x39	/* Keypad 0 */
#define BTN_1			0x08	/* Keypad 1 */
#define BTN_2			0x09	/* keypad 2 */
#define BTN_3			0x0A	/* Keypad 3 */
#define BTN_4			0x18	/* Keypad 4 */
#define BTN_5			0x19	/* Keypad 5 */
#define BTN_6			0x1A	/* Keypad 6 */
#define BTN_7			0x28	/* Keypad 7 */
#define BTN_8			0x29	/* Keypad 8 */
#define BTN_9			0x2A
#define BTN_STAR		0x38	/* Keypad * */
#define BTN_POUND		0x3A	/* Keyapd # */
#define BTN_VOLUP		0x1C	/* Volume Rocker UP */
#define BTN_VOLDN		0x2C	/* Volume Rocker DOWN */
#define BTN_SPK			0x3C	/* Speakerphone Button */
#define BTN_HOLD		0x0B	/* Hold Button */
#define BTN_FLASH		0x1B	/* Flash Button */
#define BTN_MUTE		0x0C	/* Mute Button */
#define BTN_UP			0xF7	/* Any keypad button UP */
#define SWITCHOOK_ON		0x80	/* Switchook down */
#define SWITCHOOK_OFF		0x88	/* Switchook up */

#include <linux/ioctl.h>

#define	WHEATIES_IOC_MAGIC 'w'

#define	WHEATIES_IOC_RESET	_IO(WHEATIES_IOC_MAGIC,0)
